==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/user/messages/ru/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => '<strong>Учётная запись</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Подтвердите</strong> новый e-mail адрес',
    '<strong>Permissions</strong>' => '<strong>Разрешения</strong>',
    '<strong>User</strong> modules' => '<strong>Пользовательские модули</strong>',
    '<strong>User</strong> settings' => '<strong>Настройки сайта</strong>',
    '<strong>Your</strong> profile' => '<strong>Ваш профиль</strong>',
    'All your personal data will be irrevocably deleted.' => 'Все ваши личные данные будут безвозвратно удалены.',
    'Are you really sure? *ALL* module data for your profile will be deleted!' => 'Вы точно уверены? *ВСЕ* данные модуля для Вашего профиля будут удалены!',
    'Are you sure that you want to delete your account?' => 'Вы уверены, что хотите удалить свой аккаунт?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Изменение имени пользователя может сделать некоторые ссылки непригодными, например старые ссылки на профиль.',
    'Configure' => 'Настроить',
    'Confirm' => 'Подтвердить',
    'Current password' => 'Текущий пароль',
    'Delete account' => 'Удалить учётную запись',
    'Disable' => 'Выключить',
    'Do you really want to delete your icon image?' => 'Вы действительно хотите удалить изображение иконки?',
    'Do you really want to delete your logo image?' => 'Вы действительно хотите удалить изображение логотипа?',
    'E-Mail' => 'Email',
    'E-Mail change' => 'Изменение email',
    'Enable' => 'Включить',
    'Enhance your profile with modules.' => 'Расширить профиль с помощью модулей.',
    'Enter your password to continue' => 'Введите Ваш пароль для продолжения',
    'Hello' => 'Привет',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Здесь вы можете редактировать данные Вашего профиля, которые видны на вкладке «Обо мне» в меню Вашего профиля.',
    'Hide introduction tour panel on dashboard' => 'Скрыть панель руководств на Вашей домашней странице',
    'Invalid link! Please make sure that you entered the entire url.' => 'Некорректная ссылка! Пожалуйста, убедитесь, что вы ввели правильный URL.',
    'Language' => 'Язык',
    'Modules' => 'Модули',
    'New E-Mail address' => 'Новый email',
    'New User name' => 'Новое имя пользователя',
    'Not registered users' => 'Незарегистрированные пользователи',
    'Notifications' => 'Уведомления',
    'Other users' => 'Пользователи сайта',
    'Password Recovery' => 'Восстановление пароля',
    'Permissions' => 'Доступ',
    'Profile' => 'Профиль',
    'Profile visibility' => 'Видимость профиля',
    'Registered users only' => 'Только для зарегистрированных пользователей',
    'Save' => 'Сохранить',
    'Save profile' => 'Сохранить изменения в профиле',
    'Settings' => 'Настройки',
    'Tags' => 'Теги',
    'The entered e-mail address is already in use by another user.' => 'Введённый email уже используется другим пользователем.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Эти настройки позволяют указать, какие разрешения будут иметь посетители страницы с вашим профилем. Каждый пользователь может устанавливать собственные разрешения для своего профиля.',
    'TimeZone' => 'Часовой пояс',
    'Username has been changed' => 'Имя пользователя было изменено',
    'Users' => 'Пользователи',
    'Visible for all (also unregistered users)' => 'Профиль видим для всех (включая гостей на сайте)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Мы только что отправили электронное письмо с подтверждением на Ваш новый адрес.<br>Пожалуйста проверьте Вашу почту и следуйте инструкциям внутри письма.',
    'You are currently the owner of following spaces:' => 'В настоящее время вы являетесь владельцем следующих сообществ:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Вы запросили смену своего адреса электронной почты.<br>Ваш новый адрес электронной почты - {newemail}.<br><br>Чтобы подтвердить свой новый адрес электронной почты, нажмите кнопку ниже.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Вы успешно изменили своё имя пользователя.<br>Ваше новое имя пользователя - {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Вы должны передать права владения другому пользователю или удалить эти сообщества, прежде чем сможете удалить свою учётную запись.',
    'Your account cannot be deleted!' => 'Ваша учётная запись не может быть удалена!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Ваш текущий адрес электронной почты: <b>{email}</b>. Вы можете изменить свой адрес электронной почты здесь.',
    'Your current password can be changed here.' => 'Здесь можно изменить Ваш текущий пароль.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Ваше текущее имя пользователя: <b>{username}</b>. Вы можете изменить его здесь.',
    'Your e-mail address has been successfully changed to {email}.' => 'Ваш адрес электронной почты был успешно изменен на {email}.',
    'Your friends' => 'Ваши друзья',
    'Your password has been successfully changed!' => 'Ваш пароль успешно изменен!',
    'Your username has been changed' => 'Ваше имя пользователя было изменено',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Ваше имя пользователя было успешно изменено.<br>Мы только что отправили Вам электронное письмо с новой информацией.',
    '{attribute} "{value}" was not found!' => '{attribute} со значением "{value}" не найден!',
    'Blocked users' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/ru/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Подтвердите</strong> новый e-mail адрес',
    '<strong>Permissions</strong>' => '<strong>Разрешения</strong>',
    '<strong>Your</strong> profile' => '<strong>Ваш профиль</strong>',
    'All your personal data will be irrevocably deleted.' => 'Все ваши личные данные будут безвозвратно удалены.',
    'Are you sure that you want to delete your account?' => 'Вы уверены, что хотите удалить свой аккаунт?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Изменение имени пользователя может сделать некоторые ссылки непригодными, например старые ссылки на профиль.',
    'Confirm' => 'Подтвердить',
    'Current password' => 'Текущий пароль',
    'Delete account' => 'Удалить учётную запись',
    'Do you really want to delete your icon image?' => 'Вы действительно хотите удалить изображение иконки?',
    'Do you really want to delete your logo image?' => 'Вы действительно хотите удалить изображение логотипа?',
    'E-Mail' => 'Email',
    'E-Mail change' => 'Изменение email',
    'Enter your password to continue' => 'Введите Ваш пароль для продолжения',
    'Hello' => 'Привет',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Здесь вы можете редактировать данные Вашего профиля, которые видны на вкладке «Обо мне» в меню Вашего профиля.',
    'Hide introduction tour panel on dashboard' => 'Скрыть панель руководств на Вашей домашней странице',
    'Invalid link! Please make sure that you entered the entire url.' => 'Некорректная ссылка! Пожалуйста, убедитесь, что вы ввели правильный URL.',
    'Language' => 'Язык',
    'Modules' => 'Модули',
    'New E-Mail address' => 'Новый email',
    'New User name' => 'Новое имя пользователя',
    'Not registered users' => 'Незарегистрированные пользователи',
    'Notifications' => 'Уведомления',
    'Other users' => 'Пользователи сайта',
    'Password Recovery' => 'Восстановление пароля',
    'Permissions' => 'Доступ',
    'Profile' => 'Профиль',
    'Profile visibility' => 'Видимость профиля',
    'Registered users only' => 'Только для зарегистрированных пользователей',
    'Save' => 'Сохранить',
    'Save profile' => 'Сохранить изменения в профиле',
    'The entered e-mail address is already in use by another user.' => 'Введённый email уже используется другим пользователем.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Эти настройки позволяют указать, какие разрешения будут иметь посетители страницы с вашим профилем. Каждый пользователь может устанавливать собственные разрешения для своего профиля.',
    'TimeZone' => 'Часовой пояс',
    'Username has been changed' => 'Имя пользователя было изменено',
    'Users' => 'Пользователи',
    'Visible for all (also unregistered users)' => 'Профиль видим для всех (включая гостей на сайте)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Мы только что отправили электронное письмо с подтверждением на Ваш новый адрес.<br>Пожалуйста проверьте Вашу почту и следуйте инструкциям внутри письма.',
    'You are currently the owner of following spaces:' => 'В настоящее время вы являетесь владельцем следующих сообществ:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Вы запросили смену своего адреса электронной почты.<br>Ваш новый адрес электронной почты - {newemail}.<br><br>Чтобы подтвердить свой новый адрес электронной почты, нажмите кнопку ниже.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Вы успешно изменили своё имя пользователя.<br>Ваше новое имя пользователя - {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Вы должны передать права владения другому пользователю или удалить эти сообщества, прежде чем сможете удалить свою учётную запись.',
    'Your account cannot be deleted!' => 'Ваша учётная запись не может быть удалена!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Ваш текущий адрес электронной почты: <b>{email}</b>. Вы можете изменить свой адрес электронной почты здесь.',
    'Your current password can be changed here.' => 'Здесь можно изменить Ваш текущий пароль.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Ваше текущее имя пользователя: <b>{username}</b>. Вы можете изменить его здесь.',
    'Your e-mail address has been successfully changed to {email}.' => 'Ваш адрес электронной почты был успешно изменен на {email}.',
    'Your friends' => 'Ваши друзья',
    'Your password has been successfully changed!' => 'Ваш пароль успешно изменен!',
    'Your username has been changed' => 'Ваше имя пользователя было изменено',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Ваше имя пользователя было успешно изменено.<br>Мы только что отправили Вам электронное письмо с новой информацией.',
    '{attribute} "{value}" was not found!' => '{attribute} со значением "{value}" не найден!',
    '<strong>Account</strong> Settings' => '',
    '<strong>User</strong> Account' => '',
    'Account Settings' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'Blocked users' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Profile Tags' => '',
    'You cannot use this username.' => '',
];
